# Absolute CacheBust
With Absolute CacheBust for Magento 2 you can ensure your customers are viewing the latest version of your images, CSS and JavaScript files.
This extension can be used with or without a CDN, and will also bust local versions of assets in your customers web browser cache.
Find more information at https://abscom.co/cachebust.

# Installation
The best way to add the extension is via composer.

```
composer require absolute/magento2-cache-bust
```

Once the extension has been added, update Magento 2 in the normal fashion.

```
php bin/magento setup:upgrade
```

# Web Server Configuration
Some web server configuration is required in order for requests to `yoursite.com/static/version12345/some/asset.js` to resolve correctly.
The intention is for the web server to ignore the segment `/version12345/` and process the request as if it were not there.

Add the following to the appropriate location in your web server configuration.

# Nginx

```
location ~ ^/static/version {
    rewrite ^/static/(version\d*/)?(.*)$ /static/$2 last;
}

location ~ ^/media/version {
    rewrite ^/media/(version\d*/)?(.*)$ /media/$2 last;
}
```

## Apache

```
RewriteRule ^/static/(version\d*/)?(.*)$ /static/$2 [QSA,L]
RewriteRule ^/media/(version\d*/)?(.*)$ /media/$2 [QSA,L]
```

# Usage
Once installed and configured, there are various ways to bust your Magento 2 website asset cache.

## Admin Panel Buttons
In the Magento Admin Panel go to `System > Cache Management` and you will see a new section at the bottom called 'Cache Busting'.
Clicking these buttons will update the dynamic element of the `/version12345/` and then flush the appropriate Magento caches, so on their next visit your customers will download the assets afresh.

## Command Line Interface (CLI)
In the Magento CLI tool you will see some new commands available, which can be used to bust cache during a deployment for example.

```
./bin/magento absolute:cache-bust:all
./bin/magento absolute:cache-bust:static
./bin/magento absolute:cache-bust:media
```

# Help / Support
Need help or custom development? Find us at https://absolutecommerce.co.uk.
